@@ -1,18 +1,18 @@
 from proto_formatter.comment import CommentParser
 from proto_formatter.constant import Constant
-from proto_formatter.proto import Option
-from proto_formatter.proto import ProtoBufStructure
+from proto_formatter.proto_structures import Option
+from proto_formatter.protobuf import Protobuf
 
 
 class OptionParser(Constant):
 
     @classmethod
-    def parse_and_add(cls, proto_obj: ProtoBufStructure, line, top_comment_list):
+    def parse_and_add(cls, proto_obj: Protobuf, line, top_comment_list):
         option = cls.parse_option(line, top_comment_list)
         cls.add_options(proto_obj, option)
 
     @classmethod
-    def add_options(cls, proto_obj: ProtoBufStructure, new_option):
+    def add_options(cls, proto_obj: Protobuf, new_option):
         for option in proto_obj.options:
             if option.name == new_option.name:
                 raise Exception(f'multiple option detected: {new_option.name}!')
